@@ -10,7 +10,6 @@ import requests
 from tkinter import colorchooser
 import turtle as t
 import random as ra
-from datetime import datetime
 import time
 import playsound
 from pydub import AudioSegment
@@ -35,6 +34,9 @@ import datetime
 import pytz
 import random
 import string
+import webbrowser
+def open_web(url)
+    webbrowser.open(url)
 def get_system_summary():
     try:
         os_info = platform.system() + " " + platform.release()
@@ -43,6 +45,17 @@ def get_system_summary():
         python_ver = platform.python_version()
         ip = socket.gethostbyname(socket.gethostname())
         tz = datetime.datetime.now(pytz.timezone("Asia/Tehran")).tzname()
+        return {
+            "os": os_info,
+            "cpu": cpu_info,
+            "ram": ram_info,
+            "python_version": python_ver,
+            "ip_address": ip,
+            "timezone": tz
+        }
+    except Exception as e:
+        return {"error": str(e)}
+
 def generate_password(length=12, strength="strong"):
     if strength == "simple":
         chars = string.ascii_lowercase
@@ -52,7 +65,43 @@ def generate_password(length=12, strength="strong"):
         chars = string.ascii_letters + string.digits + string.punctuation
 
     return ''.join(random.choice(chars) for _ in range(length))
+def speech_to_text(timeout=5, phrase_time_limit=10, language="fa-IR"):
+    recognizer = sr.Recognizer()
+    with sr.Microphone() as source:
+        print("🎙️ لطفاً صحبت کنید...")
+        audio = recognizer.listen(source, timeout=timeout, phrase_time_limit=phrase_time_limit)
+        try:
+            text = recognizer.recognize_google(audio, language=language)
+            return text
+        except sr.UnknownValueError:
+            return "❌ گفتار قابل تشخیص نبود"
+        except sr.RequestError:
+            return "⚠️ خطا در اتصال به سرویس گوگل"
+def speak(text, lang="auto"):
+    # تشخیص زبان
+    if lang == "auto":
+        lang = "fa" if any('\u0600' <= ch <= '\u06FF' for ch in text) else "en"
 
+    # بررسی پشتیبانی gTTS
+    supported_langs = gtts_langs.tts_langs()
+    if lang not in supported_langs:
+        fallback = "ar" if lang == "fa" else "en"
+        print(f"[!] زبان '{lang}' توسط gTTS پشتیبانی نمی‌شود. استفاده از جایگزین: '{fallback}'")
+        lang = fallback
+
+    # ساخت فایل با نام جديد
+    downloads = get_downloads_dir()
+    downloads.mkdir(parents=True, exist_ok=True)
+    filename = get_unique_filename(base_name="voice", ext=".mp3", folder=downloads)
+
+    tts = gTTS(text=text, lang=lang)
+    tts.save(str(filename))
+    pygame.mixer.init()
+    pygame.mixer.music.load(str(filename))
+    pygame.mixer.music.set_volume(1.0)
+    pygame.mixer.music.play()
+    while pygame.mixer.music.get_busy():
+        time.sleep(0.1)
 def browser(url):
     webbrowser.open(url)
 def run_app(path):
@@ -177,22 +226,13 @@ def play_mp3(path):
     while pygame.mixer.music.get_busy():
         time.sleep(0.1)
 
-def text_to_speech(txt, language, yourMP3name):
-    downloads = get_downloads_dir()
-    downloads.mkdir(parents=True, exist_ok=True)
-    filename = downloads / f"{yourMP3name}.mp3"
-
-    tts = gTTS(text=txt, lang=language)
-    tts.save(str(filename))
-
-    pygame.mixer.init()
-    pygame.mixer.music.load(str(filename))
-    pygame.mixer.music.set_volume(1.0)
-    pygame.mixer.music.play()
-
-    while pygame.mixer.music.get_busy():
-        time.sleep(0.1)
-
+def text_to_speech(text):
+    engine = pyttsx3.init()
+    voices = engine.getProperty('voices')
+    engine.setProperty('voice', voices[0].id)
+    engine.setProperty('rate', 150)
+    engine.say(text)
+    engine.runAndWait()
 import os
 
 def search_real_usage(keyword, path):
@@ -228,6 +268,8 @@ def get_unique_filename(base_name="voice", ext=".mp3", folder=None):
         i += 1
 
 def clock(unit):
+    """hour or minute or second or microseconde"""
+    from datetime import datetime
     now = datetime.now()
     if unit == "hour":
         return now.hour
@@ -242,5 +284,5 @@ def clock(unit):
 __all__ = [
     "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary",
     "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "speak","shapecursor","run_app", "get_file_size", "generate_password",
-    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser"
+    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak"
 ]
